# Wasot Projects

- multiple wasot files forming a project, connected via [links](./links.md)
- sqlite is only performance optimization (see [architecture](./architecture.md)), works without
- Works without tooling as well. Humans can navigate efficiently as well
- [Tools](./tools.md) can work easily as well

Other

- Meta data on every level, with scope (see [context and scoped variables](./context_and_scoped_variables.md))
- Tools can add scoped meta-data
- Root of document is not special -> re-linked in project via [document IDs](./document_ids.md)
